module.exports = {
	mode: "production",
	entry: "./index",
	performance: false,
	stats: {
		maxModules: 20,
		modulesSort: "!id"
	}
};
